/***************************************************************************
                           job_renamemedium.h    - ask the user for a new name 
                                                   and rename it in the database
                             -------------------
    begin                : 2004-10-08
    copyright            : (C) 2004 by Christian Mueller
    email                : cmbofh@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the license, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_RENAMEMEDIUM_H
#define JOB_RENAMEMEDIUM_H

#include "prokyon.h"

#include "jobbase.h"

class Job_RenameMedium : public JobBase  {
public:
    Job_RenameMedium(MEDIUM *_medium);

    int type() {
        return JOB_RENAME_MEDIUM;
    }

    void run();

    ~Job_RenameMedium();

private:
    MEDIUM *medium;
};

#endif
